////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
// File Name: TVP7002_VGA_to_RGB_444_DS.cmd
// Release Date: 04-22-2013
// For use with the TVP7002 EVM Kit

// Description:
// This command file programs the TVP7002 register settings for the following graphics formats:
//  - All VESA DMT graphics formats up to 162MHz

// The following Include files provide register settings that are the same for all graphics formats.
//  - TVP7002_default_settings.inc
//  - TVP7002_VGA_to_RGB_444_DS_common.inc

// The input MUX is configured for PC graphics inputs on the VGA connector input.
// Optimum Phase Sel setting will vary depending on the graphics source used.
// TVP7002 discrete sync outputs are set up to match those specified in the VESA DMT graphics standard.
// The TVP7002 is set up to use a 27MHz, external REFCLK.

// Acronyms:
// RB   Reduced Blanking
// HS   Horizontal Sync
// VS   Vertical Sync
// DS   Discrete Sync
// ES   Embedded Sync
// SOY  Sync on Y
// DMT  Display Monitor Timing
// VGA  Video Graphics Array
////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"Data Enable Output on Pin 22 of TVP7002"

WR_REG,TVP7000,0x01,0x17,0x10 // MISC Control 2, DE out, outputs enabled

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"Field ID Output on Pin 22 of TVP7002 (default)"

WR_REG,TVP7000,0x01,0x17,0x00 // MISC Control 2, FID out, outputs enabled 

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"*** 5-wire VGA to 30-bit RGB 4:4:4 DS settings for TVP7002 ***"

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 01h, 640x350 @ 85Hz, 37.861kHz, 31.500MHz, HS/VS +/-, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x34 // H-PLL Feedback Divider MSBs - 832 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x20 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x40 // HSYNC Output Width - 64 pixels
WR_REG,TVP7000,0x01,0x0E,0x20 // Sync Control 1 - HSout+ VSout-
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0xAA // AVID Start Pixel LSB - 170 (160 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x2A // AVID Stop Pixel LSB - 810 (170 + 640) pixels
WR_REG,TVP7000,0x01,0x43,0x03 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x20 // VBLK F0 Start Line Offset - 32 lines
WR_REG,TVP7000,0x01,0x45,0x20 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x5F // VBLK F0 Duration - 95 lines
WR_REG,TVP7000,0x01,0x47,0x5F // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 02h, 640x400 @ 85Hz, 37.861kHz, 31.500MHz, HS/VS -/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x34 // H-PLL Feedback Divider MSBs - 832 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x20 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x40 // HSYNC Output Width - 64 pixels
WR_REG,TVP7000,0x01,0x0E,0x04 // Sync Control 1 - HSout- VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0xAA // AVID Start Pixel LSB - 170 (160 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x2A // AVID Stop Pixel LSB - 810 (170 + 640) pixels
WR_REG,TVP7000,0x01,0x43,0x03 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2D // VBLK F0 Duration - 45 lines
WR_REG,TVP7000,0x01,0x47,0x2D // VBLK F1 Duration
      
END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 03h, 720x400 @ 85Hz, 37.927kHz, 35.500MHz, HS/VS -/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x3A // H-PLL Feedback Divider MSBs - 936  pixels
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x18 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x48 // HSYNC Output Width - 72 pixels
WR_REG,TVP7000,0x01,0x0E,0x04 // Sync Control 1 - HSout- VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0xBE // AVID Start Pixel LSB - 190 (180 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x8E // AVID Stop Pixel LSB - 910 (190 + 720) pixels
WR_REG,TVP7000,0x01,0x43,0x03 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2E // VBLK F0 Duration - 46 lines
WR_REG,TVP7000,0x01,0x47,0x2E // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 04h, 640x480 @ 60Hz, 31.469kHz, 25.175MHz, HS/VS -/-, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x32 // H-PLL Feedback Divider MSBs - 800 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x20 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x60 // HSYNC Output Width - 96 pixels
WR_REG,TVP7000,0x01,0x0E,0x00 // Sync Control 1 - HSout- VSout-
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x9A // AVID Start Pixel LSB - 154 (136 + 10 + 8) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x1A // AVID Stop Pixel LSB - 786 (154 + 640) pixels
WR_REG,TVP7000,0x01,0x43,0x03 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x0A // VBLK F0 Start Line Offset - 10 lines
WR_REG,TVP7000,0x01,0x45,0x0A // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2D // VBLK F0 Duration - 45 lines
WR_REG,TVP7000,0x01,0x47,0x2D // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 05h, 640x480 @ 72Hz, 37.861kHz, 31.500MHz, HS/VS -/-, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x34 // H-PLL Feedback Divider MSBs - 832 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x20 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x28 // HSYNC Output Width - 40 pixels
WR_REG,TVP7000,0x01,0x0E,0x00 // Sync Control 1 - HSout- VSout-
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0xB2 // AVID Start Pixel LSB - 178 (160 + 10 + 8) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x32 // AVID Stop Pixel LSB - 810 (178 + 640) pixels
WR_REG,TVP7000,0x01,0x43,0x03 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x09 // VBLK F0 Start Line Offset - 9 lines
WR_REG,TVP7000,0x01,0x45,0x09 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x28 // VBLK F0 Duration - 40 lines
WR_REG,TVP7000,0x01,0x47,0x28 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 06h, 640x480 @ 75Hz, 37.500kHz, 31.500MHz, HS/VS -/-, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x34 // H-PLL Feedback Divider MSBs - 840 pixels
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x20 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x40 // HSYNC Output Width - 64 pixels
WR_REG,TVP7000,0x01,0x0E,0x00 // Sync Control 1 - HSout- VSout-
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0xC1 // AVID Start Pixel LSB - 193 (184 + 10 - 1) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x41 // AVID Stop Pixel LSB - 833 (193 + 640) pixels
WR_REG,TVP7000,0x01,0x43,0x03 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x14 // VBLK F0 Duration - 20 Lines
WR_REG,TVP7000,0x01,0x47,0x14 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 07h, 640x480 @ 85Hz, 43.269kHz, 36.000MHz, HS/VS -/-, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x34 // H-PLL Feedback Divider MSBs - 832 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x60 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x38 // HSYNC Output Width - 56 pixels
WR_REG,TVP7000,0x01,0x0E,0x00 // Sync Control 1 - HSout- VSout-
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x92 // AVID Start Pixel LSB - 146 (136 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x12 // AVID Stop Pixel LSB - 786 (146 + 640) pixels
WR_REG,TVP7000,0x01,0x43,0x03 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1D // VBLK F0 Duration - 29 lines
WR_REG,TVP7000,0x01,0x47,0x1D // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 08h, 800x600 @ 56Hz, 35.156kHz, 36.000MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x40 // H-PLL Feedback Divider MSBs - 1024 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x58 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x48 // HSYNC Output Width - 72 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0xD2 // AVID Start Pixel LSB - 210 (200 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0xF2 // AVID Stop Pixel LSB - 1010 (210 + 800) pixels
WR_REG,TVP7000,0x01,0x43,0x03 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x19 // VBLK F0 Duration - 25 lines
WR_REG,TVP7000,0x01,0x47,0x19 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 09h, 800x600 @ 60Hz, 37.879kHz, 40.000MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x42 // H-PLL Feedback Divider MSBs - 1056 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x58 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x80 // HSYNC Output Width - 128 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0xE2 // AVID Start Pixel LSB - 226 (216 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x02 // AVID Stop Pixel LSB - 1026 (226 + 800) pixels
WR_REG,TVP7000,0x01,0x43,0x04 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1C // VBLK F0 Duration - 28 lines
WR_REG,TVP7000,0x01,0x47,0x1C // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 0Ah, 800x600 @ 72Hz, 48.077kHz, 50.000MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x41 // H-PLL Feedback Divider MSBs - 1040 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x58 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x78 // HSYNC Output Width - 120 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0xC2 // AVID Start Pixel LSB - 194 (184 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0xE2 // AVID Stop Pixel LSB - 994 (194 + 800) pixels
WR_REG,TVP7000,0x01,0x43,0x03 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x25 // VBLK F0 Start Line Offset  - 37 lines
WR_REG,TVP7000,0x01,0x45,0x25 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x42 // VBLK F0 Duration - 66 lines
WR_REG,TVP7000,0x01,0x47,0x42 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 0Bh, 800x600 @ 75Hz, 46.875kHz, 49.500MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x42 // H-PLL Feedback Divider MSBs - 1056 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x58 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x50 // HSYNC Output Width - 80 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0xF9 // AVID Start Pixel LSB - 249 (240 + 10 - 1) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x19 // AVID Stop Pixel LSB - 1049 (249 + 800) pixels
WR_REG,TVP7000,0x01,0x43,0x04 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 liine
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x19 // VBLK F0 Duration - 25 lines
WR_REG,TVP7000,0x01,0x47,0x19 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 0Ch, 800x600 @ 85Hz, 53.674kHz, 56.250MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x41 // H-PLL Feedback Divider MSBs - 1048 pixels
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x58 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x40 // HSYNC Output Width - 64 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0xE2 // AVID Start Pixel LSB - 226 (216 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x02 // AVID Stop Pixel LSB - 1026 (226 + 800) pixels
WR_REG,TVP7000,0x01,0x43,0x04 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1F // VBLK F0 Duration - 31 lines
WR_REG,TVP7000,0x01,0x47,0x1F // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 0Dh, 800x600 @ 120Hz, 76.302kHz, 73.250MHz, HS/VS +/-, VGA>RGB 444 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x3C // H-PLL Feedback Divider MSBs - 960 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xB0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width - 32 pixels
WR_REG,TVP7000,0x01,0x0E,0x20 // Sync Control 1 - HSout+ VSout-
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x7A // AVID Start Pixel LSB - 122 (112 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x9A // AVID Stop Pixel LSB - 922 (122 + 800) pixels
WR_REG,TVP7000,0x01,0x43,0x03 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 10 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x24 // VBLK F0 Duration - 45 lines
WR_REG,TVP7000,0x01,0x47,0x24 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 0Eh, 848x480 @ 60Hz, 31.020kHz, 33.750MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x44 // H-PLL Feedback Divider MSBs - 1088 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x18 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x70 // HSYNC Output Width - 112 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0xE9 // AVID Start Pixel LSB - 233 (224 + 10 - 1) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x39 // AVID Stop Pixel LSB - 1081 (233 + 848) pixels
WR_REG,TVP7000,0x01,0x43,0x04 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x06 // VBLK F0 Start Line Offset - 10 lines
WR_REG,TVP7000,0x01,0x45,0x06 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x25 // VBLK F0 Duration - 45 lines
WR_REG,TVP7000,0x01,0x47,0x25 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 10h, 1024x768 @ 60Hz, 48.363kHz, 65.000MHz, HS/VS -/-, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x54 // H-PLL Feedback Divider MSBs - 1344 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x58 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x88 // HSYNC Output Width - 136 pixels
WR_REG,TVP7000,0x01,0x0E,0x00 // Sync Control 1 - HSout- VSout-
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x32 // AVID Start Pixel LSB - 306 (296 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x32 // AVID Stop Pixel LSB - 1330 (306 + 1024) pixels
WR_REG,TVP7000,0x01,0x43,0x05 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 3 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x26 // VBLK F0 Duration - 38 lines
WR_REG,TVP7000,0x01,0x47,0x26 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 11h, 1024x768 @ 70Hz, 56.476kHz, 75.000MHz, HS/VS -/-, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x53 // H-PLL Feedback Divider MSBs - 1328 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA8 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x88 // HSYNC Output Width - 136 pixels
WR_REG,TVP7000,0x01,0x0E,0x00 // Sync Control 1 - HSout- VSout-
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x22 // AVID Start Pixel LSB - 290 (280 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x22 // AVID Stop Pixel LSB - 1314 (290 + 1024) pixels
WR_REG,TVP7000,0x01,0x43,0x05 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 3 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x26 // VBLK F0 Duration - 38 lines
WR_REG,TVP7000,0x01,0x47,0x26 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 12h, 1024x768 @ 75Hz, 60.023kHz, 78.750MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x52 // H-PLL Feedback Divider MSBs - 1312 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs       
WR_REG,TVP7000,0x01,0x03,0xA8 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x60 // HSYNC Output Width - 96 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x19 // AVID Start Pixel LSB - 281 (272 + 10 - 1) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x19 // AVID Stop Pixel LSB - 1305 (281 + 1024) pixels
WR_REG,TVP7000,0x01,0x43,0x05 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x20 // VBLK F0 Duration - 32 lines
WR_REG,TVP7000,0x01,0x47,0x20 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 13h, 1024x768 @ 85Hz, 68.677kHz, 94.500MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x56 // H-PLL Feedback Divider MSBs - 1376 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x60 // HSYNC Output Width - 96 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x3A // AVID Start Pixel LSB - 314 (304 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x3A // AVID Stop Pixel LSB - 1338 (314 + 1024) pixels
WR_REG,TVP7000,0x01,0x43,0x05 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x28 // VBLK F0 Duration - 40 lines
WR_REG,TVP7000,0x01,0x47,0x28 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 14h, 1024x768 @ 120Hz, 97.551kHz, 115.500MHz, HS/VS +/-, VGA>RGB 444 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x4A // H-PLL Feedback Divider MSBs - 1184 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA8 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width - 32 pixels
WR_REG,TVP7000,0x01,0x0E,0x20 // Sync Control 1 - HSout+ VSout-
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x7A // AVID Start Pixel LSB - 122 (112 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x7A // AVID Stop Pixel LSB - 1146 (122 + 1024) pixels
WR_REG,TVP7000,0x01,0x43,0x04 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 10 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2D // VBLK F0 Duration - 45 lines
WR_REG,TVP7000,0x01,0x47,0x2D // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 15h, 1152x864 @ 75Hz, 67.500kHz, 108.000MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x64 // H-PLL Feedback Divider MSBs - 1600 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x80 // HSYNC Output Width - 128 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x8A // AVID Start Pixel LSB - 394 (384 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x0A // AVID Stop Pixel LSB - 1546 (394 + 1152) pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x24 // VBLK F0 Duration - 36 lines
WR_REG,TVP7000,0x01,0x47,0x24 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 16h, 1280x768 @ 60Hz, 47.396kHz, 68.250MHz, HS/VS +/-, VGA>RGB 444 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x5A // H-PLL Feedback Divider MSBs - 1440 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x50 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width - 32 pixels
WR_REG,TVP7000,0x01,0x0E,0x20 // Sync Control 1 - HSout+ VSout-
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x7A // AVID Start Pixel LSB - 122 (112 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x7A // AVID Stop Pixel LSB - 1402 (122 + 1280) pixels
WR_REG,TVP7000,0x01,0x43,0x05 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 3 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x16 // VBLK F0 Duration - 22 lines
WR_REG,TVP7000,0x01,0x47,0x16 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 17h, 1280x768 @ 60Hz, 47.776kHz, 79.500MHz, HS/VS -/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x68 // H-PLL Feedback Divider MSBs - 1664 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control            
WR_REG,TVP7000,0x01,0x07,0x80 // HSYNC Output Width - 128 pixels
WR_REG,TVP7000,0x01,0x0E,0x04 // Sync Control 1 - HSout- VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x4A // AVID Start Pixel LSB - 330 (320 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x4A // AVID Stop Pixel LSB - 1610 (330 + 1280) pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 3 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1E // VBLK F0 Duration - 30 lines
WR_REG,TVP7000,0x01,0x47,0x1E // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 18h, 1280x768 @ 75Hz, 60.289kHz, 102.250MHz, HS/VS -/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x6A // H-PLL Feedback Divider MSBs - 1696 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // VCO2_CP3_RR_CP_R
WR_REG,TVP7000,0x01,0x07,0x80 // HSYNC Output Width - 128 pixels
WR_REG,TVP7000,0x01,0x0E,0x04 // Sync Control 1 - HSout- VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x5A // AVID Start Pixel LSB - 346 (336 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x5A // AVID Stop Pixel LSB - 1626 (346 + 1280) pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 3 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x25 // VBLK F0 Duration - 37 lines
WR_REG,TVP7000,0x01,0x47,0x25 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 19h, 1280x768 @ 85Hz, 68.633kHz, 117.500MHz, HS/VS -/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x6B // H-PLL Feedback Divider MSBs - 1712 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x88 // HSYNC Output Width - 136 pixels
WR_REG,TVP7000,0x01,0x0E,0x04 // Sync Control 1 - HSout- VSout+
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x6A // AVID Start Pixel LSB - 362 (352 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x6A // AVID Stop Pixel LSB - 1642 (362 + 1280) pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 3 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x29 // VBLK F0 Duration - 41 lines
WR_REG,TVP7000,0x01,0x47,0x29 // VBLK F1 Duration
       
END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 1Ah, 1280x768 @ 120Hz, 97.396kHz, 140.250MHz, HS/VS +/-, VGA>RGB 444 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x5A // H-PLL Feedback Divider MSBs - 1440 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xF0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width - 32 pixels
WR_REG,TVP7000,0x01,0x0E,0x20 // Sync Control 1 - HSout+ VSout-
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x7A // AVID Start Pixel LSB - 122 (112 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x7A // AVID Stop Pixel LSB - 1402 (122 + 1280) pixels
WR_REG,TVP7000,0x01,0x43,0x05 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 10 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2D // VBLK F0 Duration - 45 lines
WR_REG,TVP7000,0x01,0x47,0x2D // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 1Bh, 1280x800 @ 60Hz, 49.306kHz, 71.000MHz, HS/VS +/-, VGA>RGB 444 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x5A // H-PLL Feedback Divider MSBs - 1440 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width - 32 pixels
WR_REG,TVP7000,0x01,0x0E,0x20 // Sync Control 1 - HSout+ VSout-
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x7A // AVID Start Pixel LSB - 122 (112 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x7A // AVID Stop Pixel LSB - 1402 (122 + 1280) pixels
WR_REG,TVP7000,0x01,0x43,0x05 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 10 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x17 // VBLK F0 Duration - 45 lines
WR_REG,TVP7000,0x01,0x47,0x17 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 1Ch, 1280x800 @ 60Hz, 49.702kHz, 83.500MHz, HS/VS -/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x69 // H-PLL Feedback Divider MSBs - 1680 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x80 // HSYNC Output Width - 128 pixels
WR_REG,TVP7000,0x01,0x0E,0x04 // Sync Control 1 - HSout- VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x52 // AVID Start Pixel LSB - 338 (328 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x52 // AVID Stop Pixel LSB - 1618 (338 + 1280) pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 10 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1F // VBLK F0 Duration - 45 lines
WR_REG,TVP7000,0x01,0x47,0x1F // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 1Dh, 1280x800 @ 75Hz, 62.795kHz, 106.500MHz, HS/VS -/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x6A // H-PLL Feedback Divider MSBs - 1696 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x80 // HSYNC Output Width - 128 pixels
WR_REG,TVP7000,0x01,0x0E,0x04 // Sync Control 1 - HSout- VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x5A // AVID Start Pixel LSB - 346 (336 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x5A // AVID Stop Pixel LSB - 1626 (346 + 1280) pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 10 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x26 // VBLK F0 Duration - 45 lines
WR_REG,TVP7000,0x01,0x47,0x26 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 1Eh, 1280x800 @ 85Hz, 71.554kHz, 122.500MHz, HS/VS -/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x6B // H-PLL Feedback Divider MSBs - 1712 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x88 // HSYNC Output Width - 136 pixels
WR_REG,TVP7000,0x01,0x0E,0x04 // Sync Control 1 - HSout- VSout+
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x6A // AVID Start Pixel LSB - 362 (352 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x6A // AVID Stop Pixel LSB - 1642 (362 + 1280) pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 10 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2B // VBLK F0 Duration - 45 lines
WR_REG,TVP7000,0x01,0x47,0x2B // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 1Fh, 1280x800 @ 120Hz, 101.563kHz, 146.250MHz, HS/VS +/-, VGA>RGB 444 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x5A // H-PLL Feedback Divider MSBs - 1440 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xF0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width - 32 pixels
WR_REG,TVP7000,0x01,0x0E,0x20 // Sync Control 1 - HSout+ VSout-
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x7A // AVID Start Pixel LSB - 122 (112 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x7A // AVID Stop Pixel LSB - 1402 (122 + 1280) pixels
WR_REG,TVP7000,0x01,0x43,0x05 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 10 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2F // VBLK F0 Duration - 45 lines
WR_REG,TVP7000,0x01,0x47,0x2F // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 20h, 1280x960 @ 60Hz, 60.000kHz, 108.000MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x70 // H-PLL Feedback Divider MSBs - 1800 pixels
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x70 // HSYNC Output Width - 112 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0xB2 // AVID Start Pixel LSB - 434 (424 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0xB2 // AVID Stop Pixel LSB - 1714 (434 + 1280) pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x28 // VBLK F0 Duration - 40 lines
WR_REG,TVP7000,0x01,0x47,0x28 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 21h, 1280x960 @ 85Hz, 85.938kHz, 148.500MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x6C // H-PLL Feedback Divider MSBs - 1728 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE8 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0xA0 // HSYNC Output Width - 160 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x8A // AVID Start Pixel LSB - 394 (384 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x8A // AVID Stop Pixel LSB - 1674 (394 + 1280) pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x33 // VBLK F0 Duration - 51 lines
WR_REG,TVP7000,0x01,0x47,0x33 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 23h, 1280x1024 @ 60Hz, 63.981kHz, 108.000MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x69 // H-PLL Feedback Divider MSBs - 1688 pixels
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x70 // HSYNC Output Width - 112 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x72 // AVID Start Pixel LSB - 370 (360 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x72 // AVID Stop Pixel LSB - 1650 (370 + 1280) pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2A // VBLK F0 Duration - 42 lines
WR_REG,TVP7000,0x01,0x47,0x2A // VBLK F1 Duration
 
END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 24h, 1280x1024 @ 75Hz, 79.976kHz, 135.000MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x69 // H-PLL Feedback Divider MSBs - 1688 pixels
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE8 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x90 // HSYNC Output Width - 144 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x91 // AVID Start Pixel LSB - 401 (392 + 10 - 1) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x91 // AVID Stop Pixel LSB - 1681 (401 + 1280) pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2A // VBLK F0 Duration - 42 lines
WR_REG,TVP7000,0x01,0x47,0x2A // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 25h, 1280x1024 @ 85Hz, 91.146kHz, 157.500MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x6C // H-PLL Feedback Divider MSBs - 1728 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE8 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0xA0 // HSYNC Output Width - 160 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x8A // AVID Start Pixel LSB - 394 (384 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x8A // AVID Stop Pixel LSB - 1674 (394 + 1280) pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 10 lines
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x30 // VBLK F0 Duration - 45 lines
WR_REG,TVP7000,0x01,0x47,0x30 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 27h, 1360x768 @ 60Hz, 47.712kHz, 85.500MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x70 // H-PLL Feedback Divider MSBs - 1792 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x70 // HSYNC Output Width - 112 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x7A // AVID Start Pixel LSB - 378 (368 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0xCA // AVID Stop Pixel LSB - 1738 (378 + 1360) pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 3 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1B // VBLK F0 Duration - 27 lines
WR_REG,TVP7000,0x01,0x47,0x1B // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 28h, 1360x768 @ 120Hz, 97.533kHz, 148.250MHz, HS/VS +/-, VGA>RGB 444 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x5F // H-PLL Feedback Divider MSBs - 1520 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE8 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width - 32 pixels
WR_REG,TVP7000,0x01,0x0E,0x20 // Sync Control 1 - HSout+ VSout-
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x7A // AVID Start Pixel LSB - 122 (112 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0xCA // AVID Stop Pixel LSB - 1482 (122 + 1360) pixels
WR_REG,TVP7000,0x01,0x43,0x05 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 10 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2D // VBLK F0 Duration - 45 lines
WR_REG,TVP7000,0x01,0x47,0x2D // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 29h, 1400x1050 @ 60Hz, 64.744kHz, 101.000MHz, HS/VS +/-, VGA>RGB 444 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x61 // H-PLL Feedback Divider MSBs - 1560 pixels
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width - 32 pixels
WR_REG,TVP7000,0x01,0x0E,0x20 // Sync Control 1 - HSout+ VSout-
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x7A // AVID Start Pixel LSB - 122 (112 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0xF2 // AVID Stop Pixel LSB - 1522 (122 + 1400) pixels
WR_REG,TVP7000,0x01,0x43,0x05 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 3 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1E // VBLK F0 Duration - 30 lines
WR_REG,TVP7000,0x01,0x47,0x1E // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 2Ah, 1400x1050 @ 60Hz, 65.317kHz, 121.750MHz, HS/VS -/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x74 // H-PLL Feedback Divider MSBs - 1864 pixels
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x90 // HSYNC Output Width - 144 pixels
WR_REG,TVP7000,0x01,0x0E,0x04 // Sync Control 1 - HSout- VSout+
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x82 // AVID Start Pixel LSB - 386 (376 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0xFA // AVID Stop Pixel LSB - 1786 (386 + 1400) pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 3 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x27 // VBLK F0 Duration - 49 lines
WR_REG,TVP7000,0x01,0x47,0x27 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 2Bh, 1400x1050 @ 75Hz, 82.278kHz, 156.000MHz, HS/VS -/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x76 // H-PLL Feedback Divider MSBs - 1896 pixels
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x90 // HSYNC Output Width - 144 pixels
WR_REG,TVP7000,0x01,0x0E,0x04 // Sync Control 1 - HSout- VSout+
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x92 // AVID Start Pixel LSB - 402 (392 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x0A // AVID Stop Pixel LSB - 1802 (402 + 1400) pixels
WR_REG,TVP7000,0x01,0x43,0x07 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 10 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x31 // VBLK F0 Duration - 45 lines
WR_REG,TVP7000,0x01,0x47,0x31 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 2Eh, 1440x900 @ 60Hz, 55.469kHz, 88.750MHz, HS/VS +/-, VGA>RGB 444 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x64 // H-PLL Feedback Divider MSBs - 1600 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width - 32 pixels
WR_REG,TVP7000,0x01,0x0E,0x20 // Sync Control 1 - HSout+ VSout-
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x7A // AVID Start Pixel LSB - 122 (112 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x1A // AVID Stop Pixel LSB - 1562 (122 + 1440) pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 3 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1A // VBLK F0 Duration - 26 lines
WR_REG,TVP7000,0x01,0x47,0x1A // VBLK F1 Duration

END_DATASET

/////////////////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 2Fh, 1440x900 @ 60Hz, 55.935kHz, 106.500MHz, HS/VS +/-, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x77 // H-PLL Feedback Divider MSBs - 1904 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x98 // HSYNC Output Width - 152 pixels
WR_REG,TVP7000,0x01,0x0E,0x04 // Sync Control 1 - HSout+ VSout-
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x8A // AVID Start Pixel LSB - 394 (384 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x2A // AVID Stop Pixel LSB - 1834 (394 + 1440) pixels
WR_REG,TVP7000,0x01,0x43,0x07 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 3lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x22 // VBLK F0 Duration - 45 lines
WR_REG,TVP7000,0x01,0x47,0x22 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 30h, 1440x900 @ 75Hz, 70.635kHz, 136.750MHz, HS/VS -/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x79 // H-PLL Feedback Divider MSBs - 1936 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x98 // HSYNC Output Width - 152 pixels
WR_REG,TVP7000,0x01,0x0E,0x04 // Sync Control 1 - HSout- VSout+
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x9A // AVID Start Pixel LSB - 410 (400 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x3A // AVID Stop Pixel LSB - 1850 (410 + 1440) pixels
WR_REG,TVP7000,0x01,0x43,0x07 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 3 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2A // VBLK F0 Duration - 45 lines
WR_REG,TVP7000,0x01,0x47,0x2A // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 31h, 1440x900 @ 85Hz, 80.430kHz, 157.000MHz, HS/VS -/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x7A // H-PLL Feedback Divider MSBs - 1952 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x98 // HSYNC Output Width - 152 pixels
WR_REG,TVP7000,0x01,0x0E,0x04 // Sync Control 1 - HSout- VSout+
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0xA2 // AVID Start Pixel LSB - 418 (408 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x42 // AVID Stop Pixel LSB - 1858 (418 + 1440) pixels
WR_REG,TVP7000,0x01,0x43,0x07 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 3 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x30 // VBLK F0 Duration - 45 lines
WR_REG,TVP7000,0x01,0x47,0x30 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 33h, 1600x1200 @ 60Hz, 75.000kHz, 162.000MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x87 // H-PLL Feedback Divider MSBs - 2160 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0xC0 // HSYNC Output Width - 192 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0xFA // AVID Start Pixel LSB - 506 (496 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x3A // AVID Stop Pixel LSB - 2106 (506 + 1600) pixels
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x32 // VBLK F0 Duration - 50 lines
WR_REG,TVP7000,0x01,0x47,0x32 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 39h, 1680x1050 @ 60Hz, 64.674kHz, 119.000MHz, HS/VS +/-, VGA>RGB 444 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x73 // H-PLL Feedback Divider MSBs - 1840 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width - 32 pixels
WR_REG,TVP7000,0x01,0x0E,0x20 // Sync Control 1 - HSout+ VSout-
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x7A // AVID Start Pixel LSB - 122 (112 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x0A // AVID Stop Pixel LSB - 1802 (122 + 1680) pixels
WR_REG,TVP7000,0x01,0x43,0x07 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 3 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1E // VBLK F0 Duration - 45 lines
WR_REG,TVP7000,0x01,0x47,0x1E // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 3Ah, 1680x1050 @ 60Hz, 65.290kHz, 146.250MHz, HS/VS +/-, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x8C // H-PLL Feedback Divider MSBs - 2240 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0xB0 // HSYNC Output Width - 176 pixels
WR_REG,TVP7000,0x01,0x0E,0x04 // Sync Control 1 - HSout+ VSout-
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0xD2 // AVID Start Pixel LSB - 466 (456 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x62 // AVID Stop Pixel LSB - 2146 (466 + 1680) pixels
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 3 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x27 // VBLK F0 Duration - 45 lines
WR_REG,TVP7000,0x01,0x47,0x27 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 44h, 1920x1200 @ 60Hz, 74.038kHz, 154.000MHz, HS/VS +/-, VGA>RGB 444 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x82 // H-PLL Feedback Divider MSBs - 2080 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width - 32 pixels
WR_REG,TVP7000,0x01,0x0E,0x20 // Sync Control 1 - HSout+ VSout-
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x7A // AVID Start Pixel LSB - 122 (112 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0xFA // AVID Stop Pixel LSB - 2042 (122 + 1920) pixels
WR_REG,TVP7000,0x01,0x43,0x07 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 3 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x23 // VBLK F0 Duration - 45 lines
WR_REG,TVP7000,0x01,0x47,0x23 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 51h, 1366x768 @ 60Hz, 47.712kHz, 85.500MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x70 // H-PLL Feedback Divider MSBs - 1792 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x8F // HSYNC Output Width - 143 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x6E // AVID Start Pixel LSB - 366 (356 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0xC4 // AVID Stop Pixel LSB - 1732 (366 + 1366) pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 3 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1E // VBLK F0 Duration - 30 lines
WR_REG,TVP7000,0x01,0x47,0x1E // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 52h, 1920x1080 @ 60Hz, 67.500kHz, 148.500MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x89 // H-PLL Feedback Divider MSBs - 2200 pixels
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x2C // HSYNC Output Width - 44 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0xCA // AVID Start Pixel LSB - 202 (192 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x4A // AVID Stop Pixel LSB - 2122 (202 + 1920) pixels
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x04 // VBLK F0 Start Line Offset - 4 lines
WR_REG,TVP7000,0x01,0x45,0x04 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2D // VBLK F0 Duration - 29 lines
WR_REG,TVP7000,0x01,0x47,0x2D // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 53h, 1600x900 @ 60Hz, 60.000kHz, 108.000MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x70 // H-PLL Feedback Divider MSBs - 1800 pixels
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x50 // HSYNC Output Width - 80 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0xBA // AVID Start Pixel LSB - 186 (176 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0xFA // AVID Stop Pixel LSB - 1786 (186 + 1600) pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x64 // VBLK F0 Duration - 69 lines
WR_REG,TVP7000,0x01,0x47,0x64 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 54h, 2048x1152 @ 60Hz, 72.000kHz, 162.000MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x8C // H-PLL Feedback Divider MSBs - 2250 pixels
WR_REG,TVP7000,0x01,0x02,0xA0 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x50 // HSYNC Output Width - 80 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0xBA // AVID Start Pixel LSB - 186 (176 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0xBA // AVID Stop Pixel LSB - 2234 (186 + 2048) pixels
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x30 // VBLK F0 Duration - 48 lines
WR_REG,TVP7000,0x01,0x47,0x30 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 55h, 1280x720 @ 60Hz, 45.000kHz, 74.250MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x67 // H-PLL Feedback Divider MSBs - 1650 pixels
WR_REG,TVP7000,0x01,0x02,0x20 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x28 // HSYNC Output Width - 40 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x0E // AVID Start Pixel LSB - 270 (260 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x0E // AVID Stop Pixel LSB - 1550 (270 + 1280) pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x05 // VBLK F0 Start Line Offset - 5 lines
WR_REG,TVP7000,0x01,0x45,0x05 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1E // VBLK F0 Duration - 30 lines
WR_REG,TVP7000,0x01,0x47,0x1E // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 56h, 1366x768 @ 60Hz, 48.000kHz, 72.000MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x5D // H-PLL Feedback Divider MSBs - 1500 pixels
WR_REG,TVP7000,0x01,0x02,0xC0 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x38 // HSYNC Output Width - 56 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x7F // AVID Start Pixel LSB - 127 (120 + 10 - 3) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0xD5 // AVID Stop Pixel LSB - 1496 (127 + 1366) pixels
WR_REG,TVP7000,0x01,0x43,0x05 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x20 // VBLK F0 Duration - 32 lines
WR_REG,TVP7000,0x01,0x47,0x20 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: n/a, 1920x1080 @ 50Hz, 56.250kHz, 148.500MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0xA5 // H-PLL Feedback Divider MSBs - 2200 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xD8 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x2C // HSYNC Output Width - 44 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0xCA // AVID Start Pixel LSB - 202 (192 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x4A // AVID Stop Pixel LSB - 2122 (202 + 1920) pixels
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x04 // VBLK F0 Start Line Offset - 4 lines
WR_REG,TVP7000,0x01,0x45,0x04 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2D // VBLK F0 Duration - 29 lines
WR_REG,TVP7000,0x01,0x47,0x2D // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: n/a, 1280x720 @ 50Hz, 37.500kHz, 74.250MHz, HS/VS +/+, VGA>RGB 444 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_RGB_444_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x7B // H-PLL Feedback Divider MSBs - 1650 pixels
WR_REG,TVP7000,0x01,0x02,0xC0 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x28 // HSYNC Output Width - 40 pixels
WR_REG,TVP7000,0x01,0x0E,0x24 // Sync Control 1 - HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x40,0x0E // AVID Start Pixel LSB - 270 (260 + 10) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x0E // AVID Stop Pixel LSB - 1550 (270 + 1280) pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x05 // VBLK F0 Start Line Offset - 5 lines
WR_REG,TVP7000,0x01,0x45,0x05 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1E // VBLK F0 Duration - 30 lines
WR_REG,TVP7000,0x01,0x47,0x1E // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
