////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
// File Name: TVP7002_VGA_to_YCbCr_422_DS.cmd
// Release Date: 04-22-2013
// For use with the TVP7002 EVM Kit

// Description:
//  This command file programs the TVP7002 register settings for the following graphics formats:
//   - All 60Hz VESA DMT graphics formats up to 162MHz

// The following Include files provide register settings that are the same for all graphics formats.
//  - TVP7002_default_settings.inc
//  - TVP7002_VGA_to_YCbCr_422_DS_common.inc

// The input MUX is configured for PC graphics inputs on the VGA connector input.
// Optimum Phase Sel setting will vary depending on the graphics source used.
// TVP7002 discrete sync outputs are set up to match those specified in the VESA DMT graphics standard.
// The TVP7002 is set up to use a 27MHz external REFCLK.

// Acronyms:
// RB   Reduced Blanking
// HS   Horizontal Sync
// VS   Vertical Sync
// DS   Discrete Sync
// ES   Embedded Sync
// SOY  Sync on Y
// DMT  Display Monitor Timing
// VGA  Video Graphics Array
////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"Data Enable Output on Pin 22 of TVP7002"

WR_REG,TVP7000,0x01,0x17,0x10 // MISC Control 2, DE out, outputs enabled

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"Field ID Output on Pin 22 of TVP7002 (default)"

WR_REG,TVP7000,0x01,0x17,0x00 // MISC Control 2, FID out, outputs enabled 

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"*** 5-wire VGA to 20-bit YCbCr 4:2:2 DS settings for TVP7002 ***"

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 04h, 640x480 @ 60Hz, 31.469kHz, 25.175MHz, HS/VS -/-, VGA>YCbCr 422 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x32 // H-PLL Feedback Divider MSBs - 800 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x20 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x60 // HSYNC Output Width - 96 pixels
WR_REG,TVP7000,0x01,0x0E,0x12 // Sync Control 1 - auto HS/VS detection disabled, HSout- VSout-
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0xAA // AVID Start Pixel LSB - 169 (144 + 25) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x0E // AVID Stop Pixel LSB - 13 (169 + 640 + 4) - 800 pixels
WR_REG,TVP7000,0x01,0x43,0x00 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x0A // VBLK F0 Start Line Offset - 10 lines
WR_REG,TVP7000,0x01,0x45,0x0A // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2D // VBLK F0 Duration - 45 lines
WR_REG,TVP7000,0x01,0x47,0x2D // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 09h, 800x600 @ 60Hz, 37.879kHz, 40.000MHz, HS/VS +/+, VGA>YCbCr 422 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x42 // H-PLL Feedback Divider MSBs - 1056 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs 
WR_REG,TVP7000,0x01,0x03,0x58 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x80 // HSYNC Output Width - 128 pixels
WR_REG,TVP7000,0x01,0x0E,0x36 // Sync Control 1 - auto HS/VS detection disabled, HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0xF2 // AVID Start Pixel LSB - 241 (25 + 216) pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x16 // AVID Stop Pixel LSB - 1045 (241 + 800 + 4) pixels
WR_REG,TVP7000,0x01,0x43,0x04 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1C // VBLK F0 Duration - 28 lines
WR_REG,TVP7000,0x01,0x47,0x1C // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 0Eh, 848x480 @ 60Hz, 31.020kHz, 33.750MHz, HS/VS +/+, VGA>YCbCr 422 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x44 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x18 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x70 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x36 // Sync Control 1 - auto HS/VS detection disabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0xF8 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x0D // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x00 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x06 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x06 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x25 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x25 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 10h, 1024x768 @ 60Hz, 48.363kHz, 65.000MHz, HS/VS -/-, VGA>YCbCr 422 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x54 // H-PLL Feedback Divider MSBs - 1344 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x58 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x88 // HSYNC Output Width - 136 pixels
WR_REG,TVP7000,0x01,0x0E,0x12 // Sync Control 1 - auto HS/VS detection disabled, HSout- VSout-
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x42 // AVID Start Pixel LSB - 321 (25 + 296) pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x06 // AVID Stop Pixel LSB - 5 (321 + 1024 + 4) - 1344 pixels
WR_REG,TVP7000,0x01,0x43,0x00 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset - 3 lines
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x26 // VBLK F0 Duration - 38 lines
WR_REG,TVP7000,0x01,0x47,0x26 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 16h, 1280x768 @ 60Hz, 47.396kHz, 68.250MHz, HS/VS +/+, VGA>YCbCr 422 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x5A // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x50 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x32 // Sync Control 1 - auto HS/VS detection disabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x8A // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x8E // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x05 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x16 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x16 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 17h, 1280x768 @ 60Hz, 47.776kHz, 79.500MHz, HS/VS -/+, VGA>YCbCr 422 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x68 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x80 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x16 // Sync Control 1 - auto HS/VS detection disabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x5A // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x5E // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1E // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x1E // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 1Bh, 1280x800 @ 60Hz, 49.306kHz, 71.000MHz, HS/VS +/-, VGA>YCbCr 422 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x5A // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x32 // Sync Control 1 - auto HS/VS detection disabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x8A // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x8E // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x05 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x17 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x17 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 1Ch, 1280x800 @ 60Hz, 49.702kHz, 83.500MHz, HS/VS -/+, VGA>YCbCr 422 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x69 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x80 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x16 // Sync Control 1 - auto HS/VS detection disabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x62 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x66 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1F // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x1F // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 20h, 1280x960 @ 60Hz, 60.000kHz, 108.000MHz, HS/VS +/+, VGA>YCbCr 422 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x70 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x70 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x36 // Sync Control 1 - auto HS/VS detection disabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0xC2 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0xC6 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x28 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x28 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 23h, 1280x1024 @ 60Hz, 63.981kHz, 108.000MHz, HS/VS +/+, VGA>YCbCr 422 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x69 // H-PLL Feedback Divider MSBs - 1688 pixels
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs 
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x70 // HSYNC Output Width - 112 pixels
WR_REG,TVP7000,0x01,0x0E,0x36 // Sync Control 1 - auto HS/VS detection disabled, HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x82 // AVID Start Pixel LSB - 25 + HS + Hbp = 25 + 112 + 248 = 385 pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x86 // AVID Stop Pixel LSB - AVID Start + Act Pix + 4 = 385 + 1280 + 4 = 1669 pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2A // VBLK F0 Duration - 42 lines
WR_REG,TVP7000,0x01,0x47,0x2A // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 27h, 1360x768 @ 60Hz, 47.712kHz, 85.500MHz, HS/VS +/+, VGA>YCbCr 422 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x70 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x70 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x36 // Sync Control 1 - auto HS/VS detection disabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x8A // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0xDE // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1B // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x1B // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 29h, 1440x1050 @ 60Hz, 64.744kHz, 101.000MHz, HS/VS +/-, VGA>YCbCr 422 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x61 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x32 // Sync Control 1 - auto HS/VS detection disabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x8A // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x06 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1E // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x1E // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 2Ah, 1440x1050 @ 60Hz, 65.317kHz, 121.7500MHz, HS/VS -/+, VGA>YCbCr 422 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x74 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x90 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x16 // Sync Control 1 - auto HS/VS detection disabled
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x92 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x0E // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x07 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x27 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x27 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 2Eh, 1440x900 @ 60Hz, 55.469kHz, 88.750MHz, HS/VS +/-, VGA>YCbCr 422 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x64 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x32 // Sync Control 1 - auto HS/VS detection disabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x8A // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x2E // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1A // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x1A // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 2Fh, 1440x900 @ 60Hz, 55.935kHz, 106.500MHz, HS/VS -/+, VGA>YCbCr 422 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x77 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x98 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x16 // Sync Control 1 - auto HS/VS detection disabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x9A // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x3E // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x07 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x22 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x22 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 33h, 1600x1200 @ 60Hz, 75.000kHz, 162.000MHz, HS/VS +/+, VGA>YCbCr 422 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x87 // H-PLL Feedback Divider MSBs - 2160 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0xC0 // HSYNC Output Width - 192 pixels
WR_REG,TVP7000,0x01,0x0E,0x36 // Sync Control 1 - auto HS/VS detection disabled, HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x0A // AVID Start Pixel LSB - 25 + HS + Hbp = 25 + 192 + 304 = 521 pixels
WR_REG,TVP7000,0x01,0x41,0x02 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x4E // AVID Stop Pixel LSB - AVID Start + Act Pix + 4 = 521 + 1600 + 4 = 2125 pixels
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x32 // VBLK F0 Duration - 50 lines
WR_REG,TVP7000,0x01,0x47,0x32 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 39h, 1680x1050 @ 60Hz, 64.674kHz, 119.000MHz, HS/VS +/-, VGA>YCbCr 422 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x73 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x32 // Sync Control 1 - auto HS/VS detection disabled
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x8A // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x1E // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x07 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1E // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x1E // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 3Ah, 1680x1050 @ 60Hz, 65.290kHz, 146.250MHz, HS/VS -/+, VGA>YCbCr 422 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x8C // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0xB0 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x16 // Sync Control 1 - auto HS/VS detection disabled
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0xE2 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x76 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x27 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x27 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 44h, 1920x1200 @ 60Hz, 74.038kHz, 154.000MHz, HS/VS +/-, VGA>YCbCr 422 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x82 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x20 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x32 // Sync Control 1 - auto HS/VS detection disabled
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x8A // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x0E // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x23 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x23 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 51h, 1366x768 @ 60Hz, 47.712kHz, 85.500MHz, HS/VS +/+, VGA>YCbCr 422 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x70 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x8F // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x36 // Sync Control 1 - auto HS/VS detection disabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x7E // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0xD6 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x03 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x03 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1E // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x1E // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 52h, 1920x1080 @ 60Hz, 67.500kHz, 148.500MHz, HS/VS +/+, VGA>YCbCr 422 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x89 // H-PLL Feedback Divider MSBs - 2200 pixels
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x2C // HSYNC Output Width - 44 pixels
WR_REG,TVP7000,0x01,0x0E,0x36 // Sync Control 1 - auto HS/VS detection disabled, HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0xDA // AVID Start Pixel LSB - 25 + HS + Hbp = 25 + 44 + 148 = 217 pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x5E // AVID Stop Pixel LSB - AVID Start + Act Pix + 4 = 217 + 1920 + 4 = 2141 pixels
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x04 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x04 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2D // VBLK F0 Duration - 50 lines
WR_REG,TVP7000,0x01,0x47,0x2D // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 53h, 1600x900 @ 60Hz, 60.000kHz, 108.000MHz, HS/VS +/+, VGA>YCbCr 422 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x70 // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x50 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x36 // Sync Control 1 - auto HS/VS detection disabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0xCA // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x06 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x00 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x64 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x64 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 54h, 2048x1152 @ 60Hz, 72.000kHz, 162.000MHz, HS/VS +/+, VGA>YCbCr 422 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x8C // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0xA0 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x50 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x36 // Sync Control 1 - auto HS/VS detection disabled
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0xCA // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x04 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x00 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x30 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x30 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 55h, 1280x720 @ 60Hz, 45.000kHz, 74.250MHz, HS/VS +/+, VGA>YCbCr 422 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x67 // H-PLL Feedback Divider MSBs - 1650 pixels
WR_REG,TVP7000,0x01,0x02,0x20 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x28 // HSYNC Output Width - 40 pixels
WR_REG,TVP7000,0x01,0x0E,0x36 // Sync Control 1 - auto HS/VS detection disabled, HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x1E // AVID Start Pixel LSB - 25 + HS + Hbp = 25 + 40 + 220 = 285 pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x22 // AVID Stop Pixel LSB - AVID Start + Act Pix + 4 = 285 + 1280 + 4 = 1569 pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x05 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x05 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1E // VBLK F0 Duration - 50 lines
WR_REG,TVP7000,0x01,0x47,0x1E // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: 56h, 1366x768 @ 60Hz, 48.000kHz, 72.000MHz, HS/VS +/+, VGA>YCbCr 422 DS, TVP7002, RB"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x5D // H-PLL Feedback Divider MSBs
WR_REG,TVP7000,0x01,0x02,0xC0 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x38 // HSYNC Output Width
WR_REG,TVP7000,0x01,0x0E,0x36 // Sync Control 1 - auto HS/VS detection disabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x8E // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x0C // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x43,0x00 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x20 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x20 // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: n/a, 1920x1080 @ 50Hz, 56.250kHz, 148.500MHz, HS/VS +/+, VGA>YCbCr 422 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0xA5 // H-PLL Feedback Divider MSBs - 2200 pixels
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xD8 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x2C // HSYNC Output Width - 44 pixels
WR_REG,TVP7000,0x01,0x0E,0x36 // Sync Control 1 - auto HS/VS detection disabled, HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0xDA // AVID Start Pixel LSB - 25 + HS + Hbp = 25 + 44 + 148 = 217 pixels
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x5E // AVID Stop Pixel LSB - AVID Start + Act Pix + 4 = 217 + 1920 + 4 = 2141 pixels
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x04 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x04 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2D // VBLK F0 Duration - 50 lines
WR_REG,TVP7000,0x01,0x47,0x2D // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"DMT ID: n/a, 1280x720 @ 50Hz, 37.500kHz, 74.250MHz, HS/VS +/+, VGA>YCbCr 422 DS, TVP7002"

//TVP7002
INCLUDE,TVP7002_VGA_to_YCbCr_422_DS_common.inc
WR_REG,TVP7000,0x01,0x01,0x7B // H-PLL Feedback Divider MSBs - 1650 pixels
WR_REG,TVP7000,0x01,0x02,0xC0 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x07,0x28 // HSYNC Output Width - 40 pixels
WR_REG,TVP7000,0x01,0x0E,0x36 // Sync Control 1 - auto HS/VS detection disabled, HSout+ VSout+
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup

//embedded sync setup
WR_REG,TVP7000,0x01,0x40,0x1E // AVID Start Pixel LSB - 25 + HS + Hbp = 25 + 192 + 304 = 521 pixels
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel MSB
WR_REG,TVP7000,0x01,0x42,0x22 // AVID Stop Pixel LSB - AVID Start + Act Pix + 4 = 521 + 1280 + 4 = 2125 pixels
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel MSB
WR_REG,TVP7000,0x01,0x44,0x05 // VBLK F0 Start Line Offset - 1 line
WR_REG,TVP7000,0x01,0x45,0x05 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1E // VBLK F0 Duration - 50 lines
WR_REG,TVP7000,0x01,0x47,0x1E // VBLK F1 Duration

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
