///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
// File Name: TVP7002_YPbPr_to_YCbCr_422_ES.cmd
// Release Date: 04-22-2013
// For use with the TVP7002 EVM Kit

// Description:
// This command file programs the TVP7002 register settings for the following video formats:
//  - All SDTV, EDTV and HDTV YPbPr component video formats up to 162MHz

// The following Include files provide register settings that are the same for all video formats.
//  - TVP7002_default_settings.inc
//  - TVP7002_YPbPr_to_YCbCr_422_ES_common.inc

// The input MUX is configured for YPbPr inputs on the BNC inputs.
// Optimum Phase Sel setting will vary depending on the video source used.
// The TVP7002 is set up to use a 27MHz external REFCLK.

// Acronyms:
// RB   Reduced Blanking
// HS   Horizontal Sync
// VS   Vertical Sync
// DS   Discrete Sync
// ES   Embedded Sync
// SOY  Sync on Y
// DMT  Display Monitor Timing
// VGA  Video Graphics Array
////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"Data Enable Output on Pin 22 of TVP7002"

WR_REG,TVP7000,0x01,0x17,0x10 // MISC Control 2, DE out, MISC Control 2, outputs enabled

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"Field ID Output on Pin 22 of TVP7002 (default)"

WR_REG,TVP7000,0x01,0x17,0x00 // MISC Control 2, FID out, MISC Control 2, outputs enabled 

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"*** YPbPr SOY to 20-bit YCbCr 4:2:2 ES settings for TVP7002 ***"

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"480i, 30Hz, 15.734kHz, 13.5MHz, 1x PLL, YPbPr>YCbCr 422 ES, TVP7002"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_422_ES_common.inc
WR_REG,TVP7000,0x01,0x01,0x35 // H-PLL Feedback Divider MSBs  858
WR_REG,TVP7000,0x01,0x02,0xA0 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x18 // H-H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x06 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x10 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x40 // HSYNC Output Width - 64
WR_REG,TVP7000,0x01,0x0E,0x1B // Sync Control 1  HS/VSout--
WR_REG,TVP7000,0x01,0x12,0x03 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x0C // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0x1F // Input Mux Select 2, 2.5MHz SOG LPF, 0.5MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x08 // HSOUT Output Start
WR_REG,TVP7000,0x01,0x22,0x08 // MISC Control 4, Macrovision stripper enabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x18 // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x24 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x83 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x0F // Video Bandwidth Control, minimum B/W selected
//embedded syncs
WR_REG,TVP7000,0x01,0x40,0x95 // AVID Start Pixel LSB  149 (122 + 27)
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x42,0x0F // AVID Stop Pixel LSB    15 ((AVID Start + 720 + 4) - 858)
WR_REG,TVP7000,0x01,0x43,0x00 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x13 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x13 // VBLK F1 Duration
WR_REG,TVP7000,0x01,0x48,0x02 // F-bit F0 Start Line Offset
WR_REG,TVP7000,0x01,0x49,0x01 // F-bit F1 Start Line Offset

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"480i, 30Hz, 15.734kHz, 13.5MHz, 2x PLL, YPbPr>YCbCr 422 ES, TVP7002"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_422_ES_common.inc
WR_REG,TVP7000,0x01,0x01,0x6B // H-PLL Feedback Divider MSBs  1716
WR_REG,TVP7000,0x01,0x02,0x40 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x10 // H-H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x81 // PHASE SEL(5) CKDI CKDI DIV by 2
WR_REG,TVP7000,0x01,0x05,0x06 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x10 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x40 // HSYNC Output Width - 64
WR_REG,TVP7000,0x01,0x0E,0x1B // Sync Control 1  HS/VSout--
WR_REG,TVP7000,0x01,0x12,0x03 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x0C // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0x1F // Input Mux Select 2, 2.5MHz SOG LPF, 0.5MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x08 // HSOUT Output Start
WR_REG,TVP7000,0x01,0x22,0x08 // MISC Control 4 - Macrovision stripper enabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x18 // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x24 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x83 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x0F // Video Bandwidth Control, minimum B/W selected
//embedded syncs
WR_REG,TVP7000,0x01,0x40,0x90 // AVID Start Pixel LSB  144 (118 + 26)
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x42,0x0A // AVID Stop Pixel LSB    10 ((AVID Start + 720 + 4) - 858)
WR_REG,TVP7000,0x01,0x43,0x00 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x44,0x01 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x01 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x13 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x13 // VBLK F1 Duration
WR_REG,TVP7000,0x01,0x48,0x02 // F-bit F0 Start Line Offset
WR_REG,TVP7000,0x01,0x49,0x01 // F-bit F1 Start Line Offset

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"480p60, 60Hz, 15.734kHz, 27.0MHz, YPbPr>YCbCr 422 ES, TVP7002"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_422_ES_common.inc
WR_REG,TVP7000,0x01,0x01,0x35 // H-PLL Feedback Divider MSBs  858
WR_REG,TVP7000,0x01,0x02,0xa0 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x18 // H-H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x06 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x10 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x40 // HSYNC Output Width - 64
WR_REG,TVP7000,0x01,0x0E,0x1B // Sync Control 1  HS/VSout--
WR_REG,TVP7000,0x01,0x12,0x03 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x03 // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0x1F // Input Mux Select 2, 2.5MHz SOG LPF, 0.5MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x0D // HSOUT Output Start
WR_REG,TVP7000,0x01,0x22,0x08 // MISC Control 4 - Macrovision stripper enabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x18 // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x12 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x43 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3D,0x06 // Line length tolerance
WR_REG,TVP7000,0x01,0x3F,0x0F // Video Bandwidth Control, minimum B/W selected
//embedded syncs
WR_REG,TVP7000,0x01,0x40,0x93 // AVID Start Pixel LSB  147 (122 + 25)
WR_REG,TVP7000,0x01,0x41,0x00 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x42,0x0D // AVID Stop Pixel LSB    13 ((AVID Start + 720 + 4) - 858)
WR_REG,TVP7000,0x01,0x43,0x00 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x44,0x09 // VBLK F0 Start Line Offset  Vfp = 9
WR_REG,TVP7000,0x01,0x45,0x09 // VBLK F1 Start Line Offsett
WR_REG,TVP7000,0x01,0x46,0x2D // VBLK F0 Duration  45 VBLK lines
WR_REG,TVP7000,0x01,0x47,0x2D // VBLK F1 Duration  45
WR_REG,TVP7000,0x01,0x48,0x02 // F-bit F0 Start Line Offset (default)
WR_REG,TVP7000,0x01,0x49,0x01 // F-bit F1 Start Line Offset (default)

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"720p60, 60Hz, 45kHz, 74.25MHz, YPbPr>YCbCr 422 ES, TVP7002"

//TVP7002 4:2:2 out with embedded syncs, CSC bypassed for YPbPr in YCbCr out
INCLUDE,TVP7002_YPbPr_to_YCbCr_422_ES_common.inc
WR_REG,TVP7000,0x01,0x01,0x67 // H-PLL Feedback Divider MSBs  1650
WR_REG,TVP7000,0x01,0x02,0x20 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xA0 // H-H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x32 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x20 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x28 // HSYNC Output Width - 40
WR_REG,TVP7000,0x01,0x0E,0x3F // Sync Control 1 - Select SOG, HS/VSout++
WR_REG,TVP7000,0x01,0x12,0x01 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x00 // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0xCF // Input Mux Select 2, SOG LPF bypassed, 4.8MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x53 // HSOUT Output Start
WR_REG,TVP7000,0x01,0x22,0x00 // MISC Control 4 - Macrovision stripper disabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x5A // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x07 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x12 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x0F // Video Bandwidth Control, minimum B/W selected
//embedded syncs
WR_REG,TVP7000,0x01,0x40,0x47 // AVID Start Pixel LSB   327 (300 + 27)
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x42,0x4B // AVID Stop Pixel LSB   1611 (AVID Start + 1280 + 4)
WR_REG,TVP7000,0x01,0x43,0x06 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x44,0x05 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x05 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x1E // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x1E // VBLK F1 Duration
WR_REG,TVP7000,0x01,0x48,0x00 // F-bit F0 Start Line Offset (default)
WR_REG,TVP7000,0x01,0x49,0x00 // F-bit F1 Start Line Offset (default)

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"1080i30, 30Hz, 33.75kHz, 74.25MHz, YPbPr>YCbCr 422 ES, TVP7002"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_422_ES_common.inc
WR_REG,TVP7000,0x01,0x01,0x89 // PLL DIV MSB  2200
WR_REG,TVP7000,0x01,0x02,0x80 // PLL DIV LSB
WR_REG,TVP7000,0x01,0x03,0x98 // H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x32 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x20 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x2C // HSYNC Output Width - 44
WR_REG,TVP7000,0x01,0x0E,0x3F // Sync Control 1Force SOG, VS/HSout++
WR_REG,TVP7000,0x01,0x12,0x00 // H-PLL Pre-Coast 
WR_REG,TVP7000,0x01,0x13,0x00 // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0xCF // Input Mux Select 2, SOG LPF bypassed, 4.8MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x35 // HSOUT Output Start
WR_REG,TVP7000,0x01,0x22,0x00 // MISC Control 4 - Macrovision stripper disabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x5A // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x07 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x13 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x0F // Video Bandwidth Control, minimum B/W selected
//embedded syncs
WR_REG,TVP7000,0x01,0x40,0x07 // AVID Start Pixel LSB  263 (236 + 27) for SOG filter difference
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x42,0x8B // AVID Stop Pixel LSB  2187 (AVID Start + 1920 + 4)
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x44,0x02 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x02 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x16 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x17 // VBLK F1 Duration
WR_REG,TVP7000,0x01,0x48,0x00 // F-bit F0 Start Line Offset (default)
WR_REG,TVP7000,0x01,0x49,0x00 // F-bit F1 Start Line Offset (default)

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"1080i25, 25Hz, 28.125kHz, 74.25MHz, YPbPr>YCbCr 422 ES, TVP7002"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_422_ES_common.inc
WR_REG,TVP7000,0x01,0x01,0xA5 // H-PLL Feedback Divider MSBs  2640
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x90 // H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2 
WR_REG,TVP7000,0x01,0x05,0x32 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x20 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x2C // HSYNC Output Width - 44
WR_REG,TVP7000,0x01,0x0E,0x3F // Sync Control 1  HSout+
WR_REG,TVP7000,0x01,0x12,0x00 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x01 // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0xCF // Input Mux Select 2, SOG LPF bypassed, 4.8MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x35 // HSOUT Output Start
WR_REG,TVP7000,0x01,0x22,0x00 // MISC Control 4 - Macrovision stripper disabled
WR_REG,TVP7000,0x01,0x2C,0x50 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x5A // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x07 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x13 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x0F // Video Bandwidth Control, minimum B/W selected
//embedded syncs
WR_REG,TVP7000,0x01,0x40,0x05 // AVID Start Pixel LSB  261 (236 + 25) for SOG filter difference
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x42,0x89 // AVID Stop Pixel LSB  2185 (AVID Start + 1920 + 4)
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x44,0x02 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x02 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x16 // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x17 // VBLK F1 Duration
WR_REG,TVP7000,0x01,0x48,0x00 // F-bit F0 Start Line Offset (default)
WR_REG,TVP7000,0x01,0x49,0x00 // F-bit F1 Start Line Offset (default)

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"1080p60, 60Hz, 67.5kHz, 148.5MHz, YPbPr>YCbCr 422 ES, TVP7002"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_422_ES_common.inc
WR_REG,TVP7000,0x01,0x01,0x89 // H-PLL Feedback Divider MSBs  2200
WR_REG,TVP7000,0x01,0x02,0x80 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0xE0 // H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x32 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x20 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x2C // HSYNC Output Width - 44
WR_REG,TVP7000,0x01,0x0E,0x3F // Sync Control 1  HSout+
WR_REG,TVP7000,0x01,0x12,0x00 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x01 // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0xCF // Input Mux Select 2, SOG LPF bypassed, 4.8MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x35 // HSOUT Output Start
WR_REG,TVP7000,0x01,0x22,0x00 // MISC Control 4 - Macrovision stripper disabled
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x5A // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x03 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x09 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x00 // Video Bandwidth Control, maximum B/W selected
//embedded syncs
WR_REG,TVP7000,0x01,0x40,0x07 // AVID Start Pixel LSB  263 (236 + 27) for SOG filter difference
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x42,0x8B // AVID Stop Pixel LSB  2187 (AVID Start + 1920 + 4)
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x44,0x04 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x04 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2D // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x2D // VBLK F1 Duration
WR_REG,TVP7000,0x01,0x48,0x00 // F-bit F0 Start Line Offset (default)
WR_REG,TVP7000,0x01,0x49,0x00 // F-bit F1 Start Line Offset (default)

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BEGIN_DATASET

DATASET_NAME,"1080p50, 50Hz, 56.25kHz, 148.5MHz, YPbPr>YCbCr 422 ES, TVP7002"

//TVP7002
INCLUDE,TVP7002_YPbPr_to_YCbCr_422_ES_common.inc
WR_REG,TVP7000,0x01,0x01,0xA5 // H-PLL Feedback Divider MSBs  2640
WR_REG,TVP7000,0x01,0x02,0x00 // H-PLL Feedback Divider LSBs
WR_REG,TVP7000,0x01,0x03,0x90 // H-PLL Control
WR_REG,TVP7000,0x01,0x04,0x80 // H-PLL Phase Select, CKDI, CKDI, DIV2
WR_REG,TVP7000,0x01,0x05,0x32 // Clamp Start
WR_REG,TVP7000,0x01,0x06,0x20 // Clamp Width
WR_REG,TVP7000,0x01,0x07,0x2C // HSYNC Output Width - 44
WR_REG,TVP7000,0x01,0x0E,0x3F // Sync Control 1  HSout+
WR_REG,TVP7000,0x01,0x12,0x00 // H-PLL Pre-Coast
WR_REG,TVP7000,0x01,0x13,0x01 // H-PLL Post-Coast
WR_REG,TVP7000,0x01,0x1A,0xCF // Input Mux Select 2, SOG LPF bypassed, 4.8MHz CLP LPF, EXT REFCLK, HSYNC_B and VSYNC_B selected
WR_REG,TVP7000,0x01,0x21,0x35 // HSOUT Output Start
WR_REG,TVP7000,0x01,0x22,0x00 // MISC Control 4 - Macrovision stripper disabled
WR_REG,TVP7000,0x01,0x2C,0x80 // ADC Setup
WR_REG,TVP7000,0x01,0x31,0x5A // ALC Placement
//REG34h only required if MACEN bit is set in REG22h
//WR_REG,TVP7000,0x01,0x34,0x03 // Macrovision Stripper Width when internal REFCLK is used
WR_REG,TVP7000,0x01,0x34,0x09 // Macrovision Stripper Width when 27MHz EXT REFCLK is used
WR_REG,TVP7000,0x01,0x3F,0x00 // Video Bandwidth Control, maximum B/W selected
//embedded syncs
WR_REG,TVP7000,0x01,0x40,0x05 // AVID Start Pixel LSB  261 (236 + 25) for SOG filter difference
WR_REG,TVP7000,0x01,0x41,0x01 // AVID Start Pixel LSB
WR_REG,TVP7000,0x01,0x42,0x89 // AVID Stop Pixel LSB  2185 (AVID Start + 1920 + 4)
WR_REG,TVP7000,0x01,0x43,0x08 // AVID Stop Pixel LSB
WR_REG,TVP7000,0x01,0x44,0x04 // VBLK F0 Start Line Offset
WR_REG,TVP7000,0x01,0x45,0x04 // VBLK F1 Start Line Offset
WR_REG,TVP7000,0x01,0x46,0x2D // VBLK F0 Duration
WR_REG,TVP7000,0x01,0x47,0x2D // VBLK F1 Duration
WR_REG,TVP7000,0x01,0x48,0x00 // F-bit F0 Start Line Offset (default)
WR_REG,TVP7000,0x01,0x49,0x00 // F-bit F1 Start Line Offset (default)

END_DATASET

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
